
package monogram.model;

import util.Pool;

/**
 * The monogram factory opens a new pool worker thread that is used to build two monogram models. 
 * One for the macron data and one for the double vowel data.
 * When the pool thread is done this it clears the pool. 
 * 
 * @see MonogramMode
 * 
 * 
 * @author University of Waikato - Te Whare Wānanga o Waikato
 * @version 1.0
 * @since   2014-11-20 
 */

public class MonogramFactory {

    private final static MonogramModel macronModel;
    private final static MonogramModel doubleVowelModel;
   private final static ListModel blackList;

    static {
        final Pool<String> pool = new Pool<String>();
        macronModel = new MonogramModel("../data/macron", pool);
        doubleVowelModel = new MonogramModel("../data/doublevowel", pool);
        blackList = new ListModel("../data/list/blacklist.data", pool);
        pool.clear();
    }

    private MonogramFactory() {
        //hide constructor.
    }
/** monogram model for macron data (/data/macron) */
    public static MonogramModel getMacronModel() {
     
        return macronModel;
    }
/** monogram model for double vowel data (/data/doubleVowel) */
    public static MonogramModel getDoubleVowelModel() {
        return doubleVowelModel;
    }
    
    /** monogram model for black list data (/data/blacklist) */
    public static ListModel getBlackList() {
        return blackList;
  }
}
