
package tasks;

import java.io.File;
import java.util.Calendar;
import java.util.TimerTask;
import util.FileUtil;

/**
 * Sweeps the temp directory for old temp files
 * @author University of Waikato - Te Whare Wānanga o Waikato
 * @version 1.0
 * @since   2014-11-21 
 */
public class FileSweeper extends TimerTask {

    private final File directory;
    private final int minutes;

    /**
     * @param File directory to be sweeped for old temp files.
     * @param int minutes between sweepings 
     */
    public FileSweeper(File directoryToSweep, int minutes) {
        FileUtil.checkValidDir(directoryToSweep);
        directory = directoryToSweep;
        this.minutes = minutes;
    }

    @Override
    /**
     * Runs
     */
    public void run() {
        Calendar cal = Calendar.getInstance();
        cal.add(Calendar.MINUTE, minutes * -1);
        long purgeTime = cal.getTimeInMillis();
        sweep(purgeTime);
    }

    /**
     * Runs a sweep over the temp file directory.
     * @param long if a files last modified time is lest then this purge time it will be delete
     */
    private void sweep(long purgeTime) {
        final File[] listFiles = directory.listFiles();
        for (File file : listFiles) {
            if (file.lastModified() < purgeTime) {
                FileUtil.deleteFile(file);
            }
        }
    }
}
