
package util;

import com.glaforge.i18n.io.CharsetToolkit;
import java.io.File;
import java.io.IOException;

/**
 * @author University of Waikato - Te Whare Wānanga o Waikato
 * @version 1.0
 * @since   2014-11-20 
 */
public class FileUtil {

    private final String TMP_FILE_SUFFIX = "mi-tmp-";

    /**
     * Find the file type of a file. This is based of the file suffix eg(.txt) 
     * @param File file to find out the file type of. 
     * @return String file type. 
     */
    public static String guessFileType(File file) {
        int dotPos = file.getName().lastIndexOf(".");
        return dotPos != -1 ? file.getName().substring(dotPos) : null;
    }

     /**
     * Find the file charset encoding that a file used. 
     * @param File file to find out what charset encoding has been used. 
     * @return String file charset. 
     */
    public static String guessCharsetEncoding(File file) {
        String charsetEncoding = null;
        try {
            charsetEncoding = CharsetToolkit.guessEncoding(file, 4096).name().toLowerCase();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return charsetEncoding;
    }


      /**
     * Deletes a file
     * @param File file to be deleted.
     * @return boolean is file deleted. 
     */
    public static boolean deleteFile(File file) {
        if (file == null || !file.exists()) {
            return false;
        } else if (file.isFile()) {
            return file.delete();
        } else {
            File[] listFiles = file.listFiles();
            for (File listFile : listFiles) {
                deleteFile(listFile);
            }
            return file.delete();
        }
    }

       /**
     * Check to see if a file exists and is valid
     * @param File file path to be tested. Will throw error if the file dose not exists or is not valid.
     * @throws IllegalArgumentException if the file is == null
     * @throws IllegalArgumentException if the file dose not exists 
     * @throws IllegalArgumentException if the file is not a file
     */
    public static void checkValidFile(final File file) {
        if (file == null) {
            throw new IllegalArgumentException("The file '" + file
                    + "' is null!");
        }
        if (!file.exists()) {
            throw new IllegalArgumentException("The file '" + file
                    + "' does not exist!");
        }
        if (!file.isFile()) {
            throw new IllegalArgumentException("The name '" + file
                    + "' is not a file!");
        }
    }

     /**
     * Check to see if a directory exists and is valid
     * @param File directory path to be tested. Will throw error if the directory dose not exists or is not valid.\
     * @throws IllegalArgumentException if the directory is == null
     * @throws IllegalArgumentException if the directory dose not exists 
     * @throws IllegalArgumentException if the directory is not a directory
     */
    public static void checkValidDir(final File dir) {
        if (dir == null) {
            throw new IllegalArgumentException("The directory '" + dir
                    + "' is null!");
        }
        if (!dir.exists()) {
            throw new IllegalArgumentException("The directory '" + dir
                    + "' does not exist!");
        }
        if (!dir.isDirectory()) {
            throw new IllegalArgumentException("The name '" + dir
                    + "' is not a directory!");
        }
    }
}
